# API Sources

::: viadot.sources.uk_carbon_intensity.UKCarbonIntensity

::: viadot.sources.cloud_for_customers.CloudForCustomers

::: viadot.sources.exchange_rates.ExchangeRates

::: viadot.sources.cloud_for_customers.CloudForCustomers

::: viadot.sources.sharepoint.Sharepoint

::: viadot.sources.genesys.Genesys

::: viadot.sources.outlook.Outlook

::: viadot.sources.hubspot.Hubspot

::: viadot.sources.epicor.Epicor

::: viadot.sources.mindful.Mindful

::: viadot.sources.minio.MinIO
